@@ -1,19 +1,7 @@
 """
-=====================
-act.tests (act.tests)
-=====================
-
-.. currentmodule:: act.tests
-
 This module contains sample files used for testing the ARM Community Toolkit.
 Files in this module should only be used for testing, not production.
 
-.. autosummary::
-    :toctree: generated/
-
-    EXAMPLE_SONDE1
-    EXAMPLE_LCL1
-    EXAMPLE_SONDE_WILDCARD
 """
 
 from .sample_files import (EXAMPLE_SONDE1, EXAMPLE_LCL1, EXAMPLE_MET_CSV,
